Using Stevedore in Your Application — stevedore 0.11.a6.gf4c43cc documentation

### Navigation

- index
- next |
- previous |
- stevedore 0.11.a6.gf4c43cc documentation »

# Using Stevedore in Your Application

This tutorial is a step-by-step walk-through demonstrating how to define plugins and then use stevedore to load and use them in your application.

- Guidelines for Naming Plugins
  - Names and Namespaces
- Creating Plugins
  - Example Plugin Set
  - A Plugin Base Class
  - Concrete Plugins
  - Registering the Plugins
  - setuptools Metadata
- Loading the Plugins
  - Loading Drivers
  - Loading Extensions
  - Why Not Call Plugins Directly?
- Testing

See also

- Dynamic Code Patterns: Extending Your Applications with Plugins
- Using setuptools entry points
- Package Discovery and Resource Access using pkg_resources
- Using Entry Points to Write Plugins | Pylons

### Navigation

- index
- next |
- previous |
- stevedore 0.11.a6.gf4c43cc documentation »